=====
PYBBM Private Messages
=====

This is a plugin to add private messaging to the django forum solution `pybb`

Prerequisites:

`Django>=1.7`
`pybbm>=0.16`

Quick Start

1. `pip install pybbm_private_messages`
2. Add `private_messages` to your `INSTALLED_APPS` BEFORE `pybb` (it overrides some templates)
